viewportSize constant
SpacingUnit
const viewportSize
Spacing equal to the viewport size along the axis.
Implementation
static const SpacingUnit viewportSize = SpacingViewport();
Spacing equal to the viewport size along the axis.
static const SpacingUnit viewportSize = SpacingViewport();