isTight property
bool
get
isTight
Whether these constraints specify an exact size.
Returns true if the minimum and maximum width are equal AND the minimum and maximum height are equal, meaning there is only one size that satisfies these constraints.
Implementation
bool get isTight => minWidth == maxWidth && minHeight == maxHeight;